==> flowCore_1.10.0.tar.gz: flowCore/man/transformActionItem-class.Rd <==
\name{transformActionItem-class}

\docType{class}

\alias{transformActionItem-class}
\alias{transformActionItem}
\alias{print,transformActionItem-method}
\alias{Rm,transformActionItem,workFlow,character-method}
\alias{show,transformActionItem-method}

\title{Class "transformActionItem"}

\description{
  
  Class and method to capture transformation operations in a flow
  cytometry workflow.

}

\section{Objects from the Class}{
  
  Objects should be created using the \code{add} method, which creates a
  \code{transformActionItem} from a \code{\link{transform}} object
  and directly assigns it to a \code{\link{workFlow}}. Alternatively,
  one can use the \code{transformActionItem} constructor function for
  more programmatic access.
  
}


\section{Slots}{

  \describe{
    
    \item{\code{transform}:}{Object of class
      \code{"fcTransformReference"}. A reference to the
      \code{\link{transform}} object that is used for the
      transformation operation. }
    
    \item{\code{ID}:}{Object of class \code{"character"}. A unique
      identifier for the \code{actionItem}. }
    
    \item{\code{name}:}{Object of class \code{"character"}. A more
      human-readable name}
    
    \item{\code{parentView}:}{Object of class
      \code{"fcViewReference"}. A reference to the parent
      \code{\link{view}} the \code{transformActionItem} is applied on. }

    \item{\code{env}:}{Object of class \code{"environment"}. The
      evaluation environment in the \code{\link{workFlow}}. }

  }
}


\section{Extends}{
Class \code{"\linkS4class{actionItem}"}, directly.
}


\usage{

transformActionItem(ID = paste("transActionRef", guid(), sep = "_"),
    name=paste("action", identifier(get(transform)), sep =
                 "_"), parentView, transform, workflow)

}

\arguments{

  \item{workflow}{ An object of class \code{\link{workFlow}} for which a
    view is to be created. }

  \item{ID}{ A unique identifier of the view, most likely created by
    using the internal \code{guid} function. }

  \item{name}{ A more human-readable name of the view. }
  
  \item{parentView, transform}{ References to the parent
    \code{\link{view}} and \code{\link{transform}} objects,
    respectively. }
  
}

\value{

  A reference to the \code{transformActionItem} that is created inside the
  \code{\link{workFlow}} environment as a side effect of calling the
  \code{add} method.

  A \code{transformActionItem} object for the constructor.
  
}


\section{Methods}{
  \describe{
    \item{print}{\code{signature(x = "transformActionItem")}: Print
      details about the object. }
    
    \item{Rm}{\code{signature(symbol = "transformActionItem", envir =
	"workFlow", subSymbol = "character")}: Remove a
	\code{transformActionItem} from a \code{\link{workFlow}}. This
	method is recursive and will also remove all dependent
	\code{views} and \code{\link[actionItem-class]{actionItems}}.}
    
    \item{show}{\code{signature(object = "transformActionItem")}: Print
      details about the object. }
  }
  
}

\details{

  \code{transformActionItems} provide a means to bind transformation
  operations in a workflow. Each \code{transformActionItem} represents a
  single \code{\link{transform}}.
  
}

\author{ Florian Hahne }

\seealso{
	
  \code{\linkS4class{workFlow}},
  \code{\linkS4class{actionItem}},
  \code{\linkS4class{gateActionItem}},
  \code{\linkS4class{compensateActionItem}},
  \code{\linkS4class{view}}
  
}

\examples{
showClass("view")
}

\keyword{classes}

==> flowCore_1.14.1.tar.gz: flowCore/man/transformActionItem-class.Rd <==
\name{transformActionItem-class}

\docType{class}

\alias{transformActionItem-class}
\alias{transformActionItem}
\alias{print,transformActionItem-method}
\alias{Rm,transformActionItem,workFlow,character-method}
\alias{show,transformActionItem-method}

\title{Class "transformActionItem"}

\description{
  
  Class and method to capture transformation operations in a flow
  cytometry workflow.

}

\section{Objects from the Class}{
  
  Objects should be created using the \code{add} method, which creates a
  \code{transformActionItem} from a \code{\link{transform}} object
  and directly assigns it to a \code{\link{workFlow}}. Alternatively,
  one can use the \code{transformActionItem} constructor function for
  more programmatic access.
  
}


\section{Slots}{

  \describe{
    
    \item{\code{transform}:}{Object of class
      \code{"fcTransformReference"}. A reference to the
      \code{\link{transform}} object that is used for the
      transformation operation. }
    
    \item{\code{ID}:}{Object of class \code{"character"}. A unique
      identifier for the \code{actionItem}. }
    
    \item{\code{name}:}{Object of class \code{"character"}. A more
      human-readable name}
    
    \item{\code{parentView}:}{Object of class
      \code{"fcViewReference"}. A reference to the parent
      \code{\link{view}} the \code{transformActionItem} is applied on. }

    \item{\code{env}:}{Object of class \code{"environment"}. The
      evaluation environment in the \code{\link{workFlow}}. }

  }
}


\section{Extends}{
Class \code{"\linkS4class{actionItem}"}, directly.
}


\usage{

transformActionItem(ID = paste("transActionRef", guid(), sep = "_"),
    name=paste("action", identifier(get(transform)), sep =
                 "_"), parentView, transform, workflow)

}

\arguments{

  \item{workflow}{ An object of class \code{\link{workFlow}} for which a
    view is to be created. }

  \item{ID}{ A unique identifier of the view, most likely created by
    using the internal \code{guid} function. }

  \item{name}{ A more human-readable name of the view. }
  
  \item{parentView, transform}{ References to the parent
    \code{\link{view}} and \code{\link{transform}} objects,
    respectively. }
  
}

\value{

  A reference to the \code{transformActionItem} that is created inside the
  \code{\link{workFlow}} environment as a side effect of calling the
  \code{add} method.

  A \code{transformActionItem} object for the constructor.
  
}


\section{Methods}{
  \describe{
    \item{print}{\code{signature(x = "transformActionItem")}: Print
      details about the object. }
    
    \item{Rm}{\code{signature(symbol = "transformActionItem", envir =
	"workFlow", subSymbol = "character")}: Remove a
	\code{transformActionItem} from a \code{\link{workFlow}}. This
	method is recursive and will also remove all dependent
	\code{views} and \code{\link[flowCore:actionItem-class]{actionItems}}.}
    
    \item{show}{\code{signature(object = "transformActionItem")}: Print
      details about the object. }
  }
  
}

\details{

  \code{transformActionItems} provide a means to bind transformation
  operations in a workflow. Each \code{transformActionItem} represents a
  single \code{\link{transform}}.
  
}

\author{ Florian Hahne }

\seealso{
	
  \code{\linkS4class{workFlow}},
  \code{\linkS4class{actionItem}},
  \code{\linkS4class{gateActionItem}},
  \code{\linkS4class{compensateActionItem}},
  \code{\linkS4class{view}}
  
}

\examples{
showClass("view")
}

\keyword{classes}
